<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Define uma constante para o callback de sanitização.
 */
if ( ! defined( 'LGPD_CONSENT_CYFER_SANITIZE_CALLBACK' ) ) 
{
    define( 'LGPD_CONSENT_CYFER_SANITIZE_CALLBACK', 'lgpd_consent_cyfer_sanitize_callback' );
}

/**
 * Função de sanitização para as opções do LGPD Consent Cyfer.
 */
if ( ! function_exists( 'lgpd_consent_cyfer_sanitize_callback' ) ) 
{
    function lgpd_consent_cyfer_sanitize_callback( $input ) {
        $new_input = array();
        if ( isset( $input['message'] ) ) {
            $new_input['message'] = sanitize_textarea_field( $input['message'] );
        }
        if ( isset( $input['privacy_link'] ) ) {
            $new_input['privacy_link'] = esc_url_raw( $input['privacy_link'] );
        }
        if ( isset( $input['bar_bg_color'] ) ) {
            $new_input['bar_bg_color'] = sanitize_text_field( $input['bar_bg_color'] );
        }
        if ( isset( $input['text_color'] ) ) {
            $new_input['text_color'] = sanitize_text_field( $input['text_color'] );
        }
        if ( isset( $input['font_size'] ) ) {
            $new_input['font_size'] = absint( $input['font_size'] );
        }
        if ( isset( $input['button_color'] ) ) {
            $new_input['button_color'] = sanitize_text_field( $input['button_color'] );
        }
        if ( isset( $input['button_text_color'] ) ) {
            $new_input['button_text_color'] = sanitize_text_field( $input['button_text_color'] );
        }
        if ( isset( $input['button_padding'] ) ) {
            $new_input['button_padding'] = sanitize_text_field( $input['button_padding'] );
        }
        if ( isset( $input['mobile_display_mode'] ) ) {
            $new_input['mobile_display_mode'] = sanitize_text_field( $input['mobile_display_mode'] );
        }
        if ( isset( $input['mobile_icon_position'] ) ) {
            $new_input['mobile_icon_position'] = sanitize_text_field( $input['mobile_icon_position'] );
        }
        if ( isset( $input['mobile_icon_image'] ) ) {
            $new_input['mobile_icon_image'] = sanitize_text_field( $input['mobile_icon_image'] );
        }
        return $new_input;
    }
}

/**
 * Class LGPD_Consent_Cyfer_Admin
 */
class LGPD_Consent_Cyfer_Admin {

    private $options;

    public function __construct() 
    {
        $this->options = get_option( 'lgpd_consent_cyfer_options' );
    }

    public function run() 
    {
        add_action( 'admin_enqueue_scripts', array( $this, 'lgpd_consent_cyfer_enqueue_style' ) );
        add_action( 'admin_menu', array( $this, 'lgpd_consent_cyfer_add_plugin_menu' ) );
        add_action( 'admin_init', array( $this, 'lgpd_consent_cyfer_register_settings' ) );
    }

    public function lgpd_consent_cyfer_enqueue_style()
    {
        wp_enqueue_style( 'lgpd-consent-cyfer-admin-style', LGPD_CONSENT_CYFER_PLUGIN_URL . 'admin/css/lgpd-consent-cyfer-admin.css', array(), LGPD_CONSENT_CYFER_VERSION );
    }

    public function lgpd_consent_cyfer_add_plugin_menu() 
    {
        add_menu_page(
            'LGPD Consent',
            'LGPD Consent',
            'manage_options',
            'lgpd-consent-cyfer',
            array( $this, 'lgpd_consent_cyfer_display_admin_page' ),
            'dashicons-shield',
            60
        );
    }

    public function lgpd_consent_cyfer_register_settings() 
    {
        // phpcs:ignore PluginCheck.CodeAnalysis.SettingSanitization.register_settingDynamic
        register_setting( 
            'lgpd_consent_cyfer_option_group',
            'lgpd_consent_cyfer_options',
            array(
                'type'              => 'array',
                'sanitize_callback' => LGPD_CONSENT_CYFER_SANITIZE_CALLBACK
        ) );

        add_settings_section(
            'lgpd_consent_cyfer_settings_section',
            'Configurações da Notificação',
            array( $this, 'lgpd_consent_cyfer_settings_section_info' ),
            'lgpd-consent-cyfer-settings'
        );

        add_settings_field(
            'message',
            'Mensagem',
            array( $this, 'lgpd_consent_cyfer_message_callback' ),
            'lgpd-consent-cyfer-settings',
            'lgpd_consent_cyfer_settings_section'
        );

        add_settings_field(
            'privacy_link',
            'Link para Política de Privacidade',
            array( $this, 'lgpd_consent_cyfer_privacy_link_callback' ),
            'lgpd-consent-cyfer-settings',
            'lgpd_consent_cyfer_settings_section'
        );

        add_settings_field(
            'bar_bg_color',
            'Cor de Fundo da Barra',
            array( $this, 'lgpd_consent_cyfer_bar_bg_color_callback' ),
            'lgpd-consent-cyfer-settings',
            'lgpd_consent_cyfer_settings_section'
        );

        add_settings_field(
            'text_color',
            'Cor do Texto da Barra',
            array( $this, 'lgpd_consent_cyfer_text_color_callback' ),
            'lgpd-consent-cyfer-settings',
            'lgpd_consent_cyfer_settings_section'
        );

        add_settings_field(
            'font_size',
            'Tamanho da Fonte (px)',
            array( $this, 'lgpd_consent_cyfer_font_size_callback' ),
            'lgpd-consent-cyfer-settings',
            'lgpd_consent_cyfer_settings_section'
        );

        add_settings_field(
            'button_color',
            'Cor de Fundo dos Botões',
            array( $this, 'lgpd_consent_cyfer_button_color_callback' ),
            'lgpd-consent-cyfer-settings',
            'lgpd_consent_cyfer_settings_section'
        );

        add_settings_field(
            'button_text_color',
            'Cor do Texto dos Botões',
            array( $this, 'lgpd_consent_cyfer_button_text_color_callback' ),
            'lgpd-consent-cyfer-settings',
            'lgpd_consent_cyfer_settings_section'
        );

        add_settings_field(
            'button_padding',
            'Padding dos Botões',
            array( $this, 'lgpd_consent_cyfer_button_padding_callback' ),
            'lgpd-consent-cyfer-settings',
            'lgpd_consent_cyfer_settings_section'
        );

        add_settings_field(
            'mobile_display_mode',
            'Modo de Exibição no Mobile',
            array( $this, 'lgpd_consent_cyfer_mobile_display_mode_callback' ),
            'lgpd-consent-cyfer-settings',
            'lgpd_consent_cyfer_settings_section'
        );

        add_settings_field(
            'mobile_icon_position',
            'Posição do Ícone Mobile',
            array( $this, 'lgpd_consent_cyfer_mobile_icon_position_callback' ),
            'lgpd-consent-cyfer-settings',
            'lgpd_consent_cyfer_settings_section'
        );

        add_settings_field(
            'mobile_icon_image',
            'URL do Ícone Mobile',
            array( $this, 'lgpd_consent_cyfer_mobile_icon_image_callback' ),
            'lgpd-consent-cyfer-settings',
            'lgpd_consent_cyfer_settings_section'
        );
    }

    public function lgpd_consent_cyfer_settings_section_info() 
    {
        echo 'Personalize as configurações da notificação LGPD:';
    }

    public function lgpd_consent_cyfer_message_callback() 
    {
        printf(
            '<textarea id="message" name="lgpd_consent_cyfer_options[message]" rows="5" cols="50">%s</textarea>',
            isset( $this->options['message'] ) ? esc_textarea( $this->options['message'] ) : 'Utilizamos cookies para melhorar sua experiência. Ao aceitar, você concorda com nossa política de privacidade.'
        );
    }

    public function lgpd_consent_cyfer_privacy_link_callback() 
    {
        printf(
            '<input type="text" id="privacy_link" name="lgpd_consent_cyfer_options[privacy_link]" value="%s" size="50" />',
            isset( $this->options['privacy_link'] ) ? esc_attr( $this->options['privacy_link'] ) : esc_attr( home_url( '/politica-de-privacidade/' ) )
        );
    }

    public function lgpd_consent_cyfer_bar_bg_color_callback() 
    {
        printf(
            '<input type="text" id="bar_bg_color" name="lgpd_consent_cyfer_options[bar_bg_color]" value="%s" placeholder="#000000" />',
            isset( $this->options['bar_bg_color'] ) ? esc_attr( $this->options['bar_bg_color'] ) : '#000000'
        );
    }

    public function lgpd_consent_cyfer_text_color_callback() 
    {
        printf(
            '<input type="text" id="text_color" name="lgpd_consent_cyfer_options[text_color]" value="%s" placeholder="#ffffff" />',
            isset( $this->options['text_color'] ) ? esc_attr( $this->options['text_color'] ) : '#ffffff'
        );
    }

    public function lgpd_consent_cyfer_font_size_callback() 
    {
        printf(
            '<input type="number" id="font_size" name="lgpd_consent_cyfer_options[font_size]" value="%s" min="10" max="30" />',
            isset( $this->options['font_size'] ) ? esc_attr( $this->options['font_size'] ) : '14'
        );
    }

    public function lgpd_consent_cyfer_button_color_callback() 
    {
        printf(
            '<input type="text" id="button_color" name="lgpd_consent_cyfer_options[button_color]" value="%s" placeholder="#ff0000" />',
            isset( $this->options['button_color'] ) ? esc_attr( $this->options['button_color'] ) : '#ff0000'
        );
    }

    public function lgpd_consent_cyfer_button_text_color_callback() 
    {
        printf(
            '<input type="text" id="button_text_color" name="lgpd_consent_cyfer_options[button_text_color]" value="%s" placeholder="#ffffff" />',
            isset( $this->options['button_text_color'] ) ? esc_attr( $this->options['button_text_color'] ) : '#ffffff'
        );
    }

    public function lgpd_consent_cyfer_button_padding_callback() 
    {
        printf(
            '<input type="text" id="button_padding" name="lgpd_consent_cyfer_options[button_padding]" value="%s" placeholder="Ex: 10px 15px" />',
            isset( $this->options['button_padding'] ) ? esc_attr( $this->options['button_padding'] ) : '10px 15px'
        );
    }

    public function lgpd_consent_cyfer_mobile_display_mode_callback() 
    {
        $mode = isset( $this->options['mobile_display_mode'] ) ? $this->options['mobile_display_mode'] : 'bar';
        ?>
        <select id="mobile_display_mode" name="lgpd_consent_cyfer_options[mobile_display_mode]">
            <option value="bar" <?php selected( $mode, 'bar' ); ?>>Exibir Barra de Notificação</option>
            <option value="icon" <?php selected( $mode, 'icon' ); ?>>Exibir Ícone de Cookie</option>
        </select>
        <?php
    }

    public function lgpd_consent_cyfer_mobile_icon_position_callback() 
    {
        $position = isset( $this->options['mobile_icon_position'] ) ? $this->options['mobile_icon_position'] : 'right';
        ?>
        <select id="mobile_icon_position" name="lgpd_consent_cyfer_options[mobile_icon_position]">
            <option value="left" <?php selected( $position, 'left' ); ?>>Esquerda</option>
            <option value="right" <?php selected( $position, 'right' ); ?>>Direita</option>
        </select>
        <?php
    }

    public function lgpd_consent_cyfer_mobile_icon_image_callback() 
    {
        printf(
            '<input type="text" id="mobile_icon_image" name="lgpd_consent_cyfer_options[mobile_icon_image]" value="%s" placeholder="URL do ícone PNG de cookie" />',
            isset( $this->options['mobile_icon_image'] ) ? esc_attr( $this->options['mobile_icon_image'] ) : ''
        );
    }

    public function lgpd_consent_cyfer_display_admin_page() 
    {
        include LGPD_CONSENT_CYFER_PLUGIN_DIR . 'admin/partials/admin-display.php';
    }
}