<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

global $wpdb;
$cache_group = 'lgpd_consent_cyfer';
$table_name = $wpdb->prefix . 'lgpd_consent_cyfer_log';

$accepted = wp_cache_get( 'lgpd_consent_cyfer_accepted', $cache_group );
if ( false === $accepted ) {
    // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared, WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching
    $accepted = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(*) FROM `" . esc_sql( $table_name ) . "` WHERE consent = %s", 'accept' ) );
    wp_cache_set( 'lgpd_consent_cyfer_accepted', $accepted, $cache_group, 300 );
}

$refused = wp_cache_get( 'lgpd_consent_cyfer_refused', $cache_group );
if ( false === $refused ) {
    // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared, WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching
    $refused = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(*) FROM `" . esc_sql( $table_name ) . "` WHERE consent = %s", 'refuse' ) );
    wp_cache_set( 'lgpd_consent_cyfer_refused', $refused, $cache_group, 300 );
}

$results = wp_cache_get( 'lgpd_consent_cyfer_results', $cache_group );
if ( false === $results ) {
    // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared, WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching
    $results = $wpdb->get_results( "SELECT * FROM `" . esc_sql( $table_name ) . "` ORDER BY consent_date DESC LIMIT 20" );
    wp_cache_set( 'lgpd_consent_cyfer_results', $results, $cache_group, 300 );
}
?>

<h2>Logs de Consentimento</h2>
<p><strong>Aceitos:</strong> <?php echo intval( $accepted ); ?></p>
<p><strong>Recusos:</strong> <?php echo intval( $refused ); ?></p>

<?php if ( $results ) : ?>
    <table class="widefat fixed" cellspacing="0">
        <thead>
            <tr>
                <th>ID</th>
                <th>Consentimento</th>
                <th>IP</th>
                <th>User Agent</th>
                <th>Data</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ( $results as $log ) : ?>
                <tr>
                    <td><?php echo esc_html( $log->id ); ?></td>
                    <td><?php echo esc_html( $log->consent ); ?></td>
                    <td><?php echo esc_html( $log->ip_address ); ?></td>
                    <td><?php echo esc_html( $log->user_agent ); ?></td>
                    <td><?php echo esc_html( $log->consent_date ); ?></td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
<?php else : ?>
    <p>Nenhum log encontrado.</p>
<?php endif; ?>