<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class LGPD_Consent_Cyfer
 *
 * Responsável por instanciar as partes Admin e Public.
 */
class LGPD_Consent_Cyfer {

    protected $plugin_admin;
    protected $plugin_public;

    public function __construct() {
        if ( is_admin() ) {
            $this->plugin_admin = new LGPD_Consent_Cyfer_Admin();
        }
        $this->plugin_public = new LGPD_Consent_Cyfer_Public();

        // Registra o filtro para adicionar metadados na listagem de plugins.
        add_filter( 'plugin_row_meta', array( $this, 'lgpd_consent_cyfer_plugin_row_meta' ), 10, 4 );
    }

    public function run() {
        if ( is_admin() ) {
            $this->plugin_admin->run();
        }
        $this->plugin_public->run();
    }

    /**
     * Adiciona o link de doação na linha do plugin na página de plugins.
     *
     * @param array  $plugin_meta Metadados atuais do plugin.
     * @param string $plugin_file O caminho relativo do arquivo principal do plugin.
     * @param array  $plugin_data Os dados do plugin (do cabeçalho).
     * @param string $status      O status do plugin.
     * @return array Metadados atualizados.
     */
    public function lgpd_consent_cyfer_plugin_row_meta( $plugin_meta, $plugin_file, $plugin_data, $status ) 
    {
        if ( $plugin_file === plugin_basename( LGPD_CONSENT_CYFER_PLUGIN_FILE ) ) {
            $donate_link = 'https://buymeacoffee.com/cyfer';
            if ( ! empty( $donate_link ) ) {
                $plugin_meta[] = '<a href="' . esc_url( $donate_link ) . '" target="_blank" rel="noopener noreferrer">' . esc_html__( 'Buy Me a Coffee', 'lgpd-consent' ) . '</a>';
            }
        }
        return $plugin_meta;
    }
}