<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Class LGPD_Consent_Cyfer_Public
 */
class LGPD_Consent_Cyfer_Public {

    private $options;

    public function __construct() 
    {
        $this->options = get_option( 'lgpd_consent_cyfer_options' );
    }

    public function run() 
    {
        add_action( 'wp_enqueue_scripts', array( $this, 'lgpd_consent_cyfer_enqueue_assets' ) );
        add_action( 'wp_footer', array( $this, 'lgpd_consent_cyfer_maybe_display_consent_bar' ) );
        add_shortcode( 'lgpd_consent_cyfer', array( $this, 'lgpd_consent_cyfer_consent_bar_shortcode' ) );
        add_action( 'wp_ajax_lgpd_consent_cyfer_save_consent', array( $this, 'lgpd_consent_cyfer_save_consent' ) );
        add_action( 'wp_ajax_nopriv_lgpd_consent_cyfer_save_consent', array( $this, 'lgpd_consent_cyfer_save_consent' ) );
    }

    public function lgpd_consent_cyfer_enqueue_assets() 
    {
        wp_enqueue_style( 'lgpd-consent-cyfer-style', LGPD_CONSENT_CYFER_PLUGIN_URL . 'public/css/lgpd-consent-cyfer.css', array(), LGPD_CONSENT_CYFER_VERSION );
        wp_enqueue_script( 'lgpd-consent-cyfer-head', LGPD_CONSENT_CYFER_PLUGIN_URL . 'public/js/lgpd-consent-cyfer-head.js', array(), LGPD_CONSENT_CYFER_VERSION, false );
        wp_enqueue_script( 'lgpd-consent-cyfer-script', LGPD_CONSENT_CYFER_PLUGIN_URL . 'public/js/lgpd-consent-cyfer.js', array( 'jquery' ), LGPD_CONSENT_CYFER_VERSION, true );
        wp_localize_script( 'lgpd-consent-cyfer-script', 'lgpdConsentCyfer', array(
            'ajax_url'      => admin_url( 'admin-ajax.php' ),
            'consent_nonce' => wp_create_nonce( 'lgpd_consent_cyfer_nonce' )
        ) );
    }

    public function lgpd_consent_cyfer_maybe_display_consent_bar() 
    {
        if ( isset( $_COOKIE['lgpd_consent_cyfer'] ) ) {
            return;
        }
        echo wp_kses_post( $this->lgpd_consent_cyfer_get_consent_bar_html() );
    }

    public function lgpd_consent_cyfer_consent_bar_shortcode() 
    {
        if ( isset( $_COOKIE['lgpd_consent_cyfer'] ) ) {
            return '';
        }
        return wp_kses_post( $this->lgpd_consent_cyfer_get_consent_bar_html() );
    }

    private function lgpd_consent_cyfer_get_consent_bar_html() 
    {
        ob_start();
        include LGPD_CONSENT_CYFER_PLUGIN_DIR . 'public/partials/lgpd-consent-cyfer-display.php';
        return ob_get_clean();
    }

    public function lgpd_consent_cyfer_save_consent() 
    {
        check_ajax_referer( 'lgpd_consent_cyfer_nonce', 'nonce' );
        $consent = isset( $_POST['consent'] ) ? sanitize_text_field( wp_unslash( $_POST['consent'] ) ) : '';
    
        if ( $consent ) {
            setcookie( 'lgpd_consent_cyfer', $consent, time() + 30 * DAY_IN_SECONDS, COOKIEPATH );
    
            global $wpdb;
            $table_name = $wpdb->prefix . 'lgpd_consent_cyfer_log';
            $ip_address = isset( $_SERVER['REMOTE_ADDR'] ) ? sanitize_text_field( wp_unslash( $_SERVER['REMOTE_ADDR'] ) ) : '';
            $user_agent = isset( $_SERVER['HTTP_USER_AGENT'] ) ? sanitize_text_field( wp_unslash( $_SERVER['HTTP_USER_AGENT'] ) ) : '';
            
            // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching
            $wpdb->insert(
                $table_name,
                array(
                    'consent'      => $consent,
                    'ip_address'   => $ip_address,
                    'user_agent'   => $user_agent,
                    'consent_date' => current_time( 'mysql' )
                ),
                array(
                    '%s',
                    '%s',
                    '%s',
                    '%s'
                )
            );
            
            wp_send_json_success();
        }
        wp_send_json_error();
    }   
}